import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manages an Okta Policy
 *
 * @schema CfnPolicyProps
 */
export interface CfnPolicyProps {
    /**
     * Specifies the type of Policy.
     *
     * @schema CfnPolicyProps#Type
     */
    readonly type: CfnPolicyPropsType;
    /**
     * Name of the Policy
     *
     * @schema CfnPolicyProps#Name
     */
    readonly name: string;
    /**
     * Description of the Policy.
     *
     * @schema CfnPolicyProps#Description
     */
    readonly description: string;
    /**
     * Priority of the Policy
     *
     * @schema CfnPolicyProps#Priority
     */
    readonly priority?: number;
    /**
     * @schema CfnPolicyProps#Conditions
     */
    readonly conditions?: any;
}
/**
 * Converts an object of type 'CfnPolicyProps' to JSON representation.
 */
export declare function toJson_CfnPolicyProps(obj: CfnPolicyProps | undefined): Record<string, any> | undefined;
/**
 * Specifies the type of Policy.
 *
 * @schema CfnPolicyPropsType
 */
export declare enum CfnPolicyPropsType {
    /** OKTA_SIGN_ON */
    OKTA_SIGN_ON = "OKTA_SIGN_ON",
    /** PASSWORD */
    PASSWORD = "PASSWORD",
    /** MFA_ENROLL */
    MFA_ENROLL = "MFA_ENROLL",
    /** OAUTH_AUTHORIZATION_POLICY */
    OAUTH_AUTHORIZATION_POLICY = "OAUTH_AUTHORIZATION_POLICY",
    /** IDP_DISCOVERY */
    IDP_DISCOVERY = "IDP_DISCOVERY",
    /** ACCESS_POLICY */
    ACCESS_POLICY = "ACCESS_POLICY"
}
/**
 * A CloudFormation `Okta::Policy::Policy`
 *
 * @cloudformationResource Okta::Policy::Policy
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-okta-resource-providers.git
 */
export declare class CfnPolicy extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Okta::Policy::Policy";
    /**
     * Resource props.
     */
    readonly props: CfnPolicyProps;
    /**
     * Attribute `Okta::Policy::Policy.Id`
     * @link https://github.com/aws-ia/cloudformation-okta-resource-providers.git
     */
    readonly attrId: string;
    /**
     * Create a new `Okta::Policy::Policy`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnPolicyProps);
}
